VTableDecl

Enum VTableDecl 

pub enum VTableDecl {
    NotDynCompatible,
    Lazy,
    VTable(GlobalDeclRef),
    Unknown(String),
}
The virtual table instance for a trait implementation.

Variants



NotDynCompatible

The trait is not dyn-compatible, so no vtable exists.



Lazy

The trait is dyn-compatible, but we have not computed a vtable for it, as it is not used.



VTable(GlobalDeclRef)

The trait is dyn-compatible, and we have computed a vtable for it.



Unknown(String)

We don’t support computing a vtable for this impl; the string explains why.

Implementations

Source

impl VTableDecl

pub fn is_not_dyn_compatible(&self) -> bool

pub fn is_lazy(&self) -> bool

pub fn is_vtable(&self) -> bool

pub fn is_unknown(&self) -> bool

Source

impl VTableDecl

pub fn as_not_dyn_compatible(&self) -> Option<()>

pub fn as_lazy(&self) -> Option<()>

pub fn as_vtable(&self) -> Option<&GlobalDeclRef>

pub fn as_unknown(&self) -> Option<&String>

Source

impl VTableDecl

pub fn as_not_dyn_compatible_mut(&mut self) -> Option<()>

pub fn as_lazy_mut(&mut self) -> Option<()>

pub fn as_vtable_mut(&mut self) -> Option<&mut GlobalDeclRef>

pub fn as_unknown_mut(&mut self) -> Option<&mut String>