pub struct TraitImpl {
pub def_id: TraitImplId,
pub item_meta: ItemMeta,
pub src: TraitImplSource,
pub impl_trait: TraitDeclRef,
pub is_negative: bool,
pub is_unsafe: bool,
pub generics: GenericParams,
pub implied_trait_refs: IndexVec<TraitClauseId, TraitRef>,
pub consts: IndexMap<AssocConstId, GlobalDeclRef>,
pub types: IndexMap<AssocTypeId, Binder<TraitAssocTyImpl>>,
pub methods: IndexMap<TraitMethodId, Binder<FunDeclRef>>,
pub vtable: VTableDecl,
}Expand description
A trait implementation.
For instance:
impl Foo for List {
type Bar = ...
fn baz(...) { ... }
}Fields
def_id: TraitImplIditem_meta: ItemMetasrc: TraitImplSourceimpl_trait: TraitDeclRefThe information about the implemented trait. Note that this contains the instantiation of the “parent” clauses.
is_negative: boolWhether this is a negative impl (impl !Trait for Type).
is_unsafe: boolWhether this is an unsafe impl.
generics: GenericParamsimplied_trait_refs: IndexVec<TraitClauseId, TraitRef>The trait references for the parent clauses (see TraitDecl).
consts: IndexMap<AssocConstId, GlobalDeclRef>The implemented associated constants.
types: IndexMap<AssocTypeId, Binder<TraitAssocTyImpl>>The implemented associated types.
methods: IndexMap<TraitMethodId, Binder<FunDeclRef>>The implemented methods
vtable: VTableDeclThe virtual table instance for this trait implementation.
Implementations
Sourceimpl TraitImpl
impl TraitImpl
pub fn methods(&self) -> impl Iterator<Item = &Binder<FunDeclRef>>
Sourcepub fn is_unsafe_to_declare(&self, _krate: &TranslatedCrate) -> bool
pub fn is_unsafe_to_declare(&self, _krate: &TranslatedCrate) -> bool
Whether this trait impl is unsafe to declare, because it is an unsafe impl (safety.unsafe-impl)
or it has an unsafe attribute (safety.unsafe-attribute).